@@ -125,12 +125,18 @@ qx.Class.define("callbackery.ui.form.Auto", {
             }
 
             if (s.set) {
+                if (s.widget == 'date') {
+                    if (s.set.value) {
+                        var dateValue = s.set.value * 1000; // incoming epoch seconds
+                        delete s.set.value;
+                        control.setValue(new Date(dateValue));
+                    }
+                }
                 if (s.set.filter){
                     s.set.filter = RegExp(s.filter);
                 }
                 control.set(s.set);
             }
-
  
             this._ctrl[s.key] = control;
             form.add(control, s.label != null ? this['tr'](s.label) : null, null, s.key,null,note);
